@@ -25,7 +25,8 @@ def pytest_generate_tests(metafunc):
     # for any function that takes a "tabletfile" argument return the path to
     # a tablet file
     if "tabletfile" in metafunc.fixturenames:
-        metafunc.parametrize("tabletfile", [f for f in datadir().glob("*.tablet")])
+        files = [f for f in datadir().glob("*.tablet")]
+        metafunc.parametrize("tabletfile", files, ids=[f.name for f in files])
 
 
 def test_device_match(tabletfile):
@@ -40,7 +41,7 @@ def test_device_match(tabletfile):
         if not match or match == "generic":
             continue
 
-        bus, vid, pid = match.split(":")[:3]  # skip the name part of the match
+        bus, vid, pid = match.split("|")[:3]  # skip the name part of the match
         assert bus in [
             "usb",
             "bluetooth",
@@ -61,7 +62,7 @@ def test_no_receiver_id(tabletfile):
     config.optionxform = lambda option: option
     config.read(tabletfile)
 
-    receivers = ["usb:{:04x}:{:04x}".format(*r) for r in WACOM_RECEIVER_USBIDS]
+    receivers = ["usb|{:04x}|{:04x}".format(*r) for r in WACOM_RECEIVER_USBIDS]
     for match in config["Device"]["DeviceMatch"].split(";"):
         assert match not in receivers
 
